@@ -1,7 +1,7 @@
 #!/bin/bash
 ##
-## Copyright (C) 2003-2005, Marcelo E. Magallon <mmagallo[]debian org>
-## Copyright (C) 2003-2005, Milan Ikits <milan ikits[]ieee org>
+## Copyright (C) 2003-2006, Marcelo E. Magallon <mmagallo[]debian org>
+## Copyright (C) 2003-2006, Milan Ikits <milan ikits[]ieee org>
 ##
 ## This program is distributed under the terms and conditions of the GNU
 ## General Public License Version 2 as published by the Free Software
@@ -56,6 +56,8 @@ if [ ! -d $1 ] ; then
 	GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI 0x8973
 	GL_NUM_LOOPBACK_COMPONENTS_ATI 0x8974
 	GL_COLOR_ALPHA_PAIRING_ATI 0x8975
+    GL_SWIZZLE_STRQ_ATI 0x897A
+    GL_SWIZZLE_STRQ_DQ_ATI 0x897B
 EOT
 
 # fix WGL_ATI_pixel_format_float
@@ -160,6 +162,14 @@ EOT
 	typedef unsigned int GLhandleARB
 EOT
 
+# add missing functions to GL_ARB_transpose_matrix
+	cat >> $1/GL_ARB_transpose_matrix <<EOT
+	void glLoadTransposeMatrixfARB (GLfloat m[16])
+	void glLoadTransposeMatrixdARB (GLdouble m[16])
+	void glMultTransposeMatrixfARB (GLfloat m[16])
+	void glMultTransposeMatrixdARB (GLdouble m[16])
+EOT
+
 # fix const correctness in GL_ARB_shader_objects
 #    perl -e 's/(.+glUniform.*(fv|iv).+)(GLfloat\*.+|GLint\*.+)/\1const \3/;' -pi $1/GL_ARB_shader_objects
 
